@@ -22,6 +22,7 @@
 #endif
 
 #include "sox.h"
+#include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
 
@@ -60,18 +61,21 @@ int main(int argc, char * argv[])
   args[0] = (char *)in, assert(sox_effect_options(e, 1, args) == SOX_SUCCESS);
   /* This becomes the first `effect' in the chain */
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
+  free(e);
 
   /* Create the `vol' effect, and initialise it with the desired parameters: */
   e = sox_create_effect(sox_find_effect("vol"));
   args[0] = "3dB", assert(sox_effect_options(e, 1, args) == SOX_SUCCESS);
   /* Add the effect to the end of the effects processing chain: */
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
+  free(e);
 
   /* Create the `flanger' effect, and initialise it with default parameters: */
   e = sox_create_effect(sox_find_effect("flanger"));
   assert(sox_effect_options(e, 0, NULL) == SOX_SUCCESS);
   /* Add the effect to the end of the effects processing chain: */
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
+  free(e);
 
   /* The last effect in the effect chain must be something that only consumes
    * samples; in this case, we use the built-in handler that outputs
@@ -79,6 +83,7 @@ int main(int argc, char * argv[])
   e = sox_create_effect(sox_find_effect("output"));
   args[0] = (char *)out, assert(sox_effect_options(e, 1, args) == SOX_SUCCESS);
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
+  free(e);
 
   /* Flow samples through the effects processing chain until EOF is reached */
   sox_flow_effects(chain, NULL, NULL);
