@@ -37,12 +37,13 @@
   #include <magic.h>
 #endif
 
-#define AUTO_DETECT_SIZE 4096
+#define PIPE_AUTO_DETECT_SIZE 256 /* Only as much as we can rewind a pipe */
+#define AUTO_DETECT_SIZE 4096     /* For seekable file, so no restriction */
 
 static char const * auto_detect_format(sox_format_t * ft, char const * ext)
 {
   char data[AUTO_DETECT_SIZE];
-  size_t len = lsx_readbuf(ft, data, sizeof(data));
+  size_t len = lsx_readbuf(ft, data, ft->seekable? sizeof(data) : PIPE_AUTO_DETECT_SIZE);
   #define CHECK(type, p2, l2, d2, p1, l1, d1) if (len >= p1 + l1 && \
       !memcmp(data + p1, d1, (size_t)l1) && !memcmp(data + p2, d2, (size_t)l2)) return #type;
   CHECK(voc   , 0, 0, ""     , 0, 20, "Creative Voice File\x1a")
@@ -56,10 +57,12 @@ static char const * auto_detect_format(sox_format_t * ft, char const * ext)
   CHECK(txw   , 0, 0, ""     , 0,  6, "LM8953")
   CHECK(sndt  , 0, 0, ""     , 0,  6, "SOUND\x1a")
   CHECK(vorbis, 0, 4, "OggS" , 29, 6, "vorbis")
+  CHECK(opus  , 0, 4, "OggS" , 28, 8, "OpusHead")
   CHECK(speex , 0, 4, "OggS" , 28, 6, "Speex")
   CHECK(hcom  ,65, 4, "FSSD" , 128,4, "HCOM")
   CHECK(wav   , 0, 4, "RIFF" , 8,  4, "WAVE")
   CHECK(wav   , 0, 4, "RIFX" , 8,  4, "WAVE")
+  CHECK(wav   , 0, 4, "RF64" , 8,  4, "WAVE")
   CHECK(aiff  , 0, 4, "FORM" , 8,  4, "AIFF")
   CHECK(aifc  , 0, 4, "FORM" , 8,  4, "AIFC")
   CHECK(8svx  , 0, 4, "FORM" , 8,  4, "8SVX")
@@ -100,7 +103,7 @@ static char const * auto_detect_format(sox_format_t * ft, char const * ext)
         magic_load(magic, NULL);
     }
     if (magic)
-      filetype = magic_buffer(magic, data, sizeof(data));
+      filetype = magic_buffer(magic, data, len);
     if (filetype && strncmp(filetype, "application/octet-stream", (size_t)24) &&
           !lsx_strends(filetype, "/unknown") &&
           strncmp(filetype, "text/plain", (size_t)10) )
@@ -141,6 +144,7 @@ static sox_encodings_info_t const s_sox_encodings_info[] = {
   {sox_encodings_lossy2, "AMR-NB"       , "AMR-NB"},
   {sox_encodings_lossy2, "CVSD"         , "CVSD"},
   {sox_encodings_lossy2, "LPC10"        , "LPC10"},
+  {sox_encodings_lossy2, "Opus"         , "Opus"},
 };
 
 assert_static(array_length(s_sox_encodings_info) == SOX_ENCODINGS,
@@ -181,13 +185,14 @@ unsigned sox_precision(sox_encoding_t encoding, unsigned bits_per_sample)
 
     case SOX_ENCODING_GSM:
     case SOX_ENCODING_VORBIS:
+    case SOX_ENCODING_OPUS:
     case SOX_ENCODING_AMR_WB:
     case SOX_ENCODING_AMR_NB:
     case SOX_ENCODING_LPC10:      return !bits_per_sample? 16: 0;
 
     case SOX_ENCODING_WAVPACKF:
-    case SOX_ENCODING_FLOAT:      return bits_per_sample == 32 ? 24: bits_per_sample == 64 ? 53: 0;
-    case SOX_ENCODING_FLOAT_TEXT: return !bits_per_sample? 53: 0;
+    case SOX_ENCODING_FLOAT:      return bits_per_sample == 32 ? 25: bits_per_sample == 64 ? 54: 0;
+    case SOX_ENCODING_FLOAT_TEXT: return !bits_per_sample? 54: 0;
 
     case SOX_ENCODINGS:
     case SOX_ENCODING_UNKNOWN:    break;
@@ -342,7 +347,7 @@ static int sox_checkformat(sox_format_t * ft)
     return SOX_EOF;
   }
   if (!ft->signal.precision) {
-    lsx_fail_errno(ft,SOX_EFMT,"data encoding was not specified");
+    lsx_fail_errno(ft,SOX_EFMT,"data encoding or sample size was not specified");
     return SOX_EOF;
   }
   return SOX_SUCCESS;
@@ -406,16 +411,17 @@ static void UNUSED rewind_pipe(FILE * fp)
 /* _FSTDIO is for Torek stdio (i.e. most BSD-derived libc's)
  * In theory, we no longer need to check _NEWLIB_VERSION or __APPLE__ */
 #if defined _FSTDIO || defined _NEWLIB_VERSION || defined __APPLE__
-  fp->_p -= AUTO_DETECT_SIZE;
-  fp->_r += AUTO_DETECT_SIZE;
+  fp->_p -= PIPE_AUTO_DETECT_SIZE;
+  fp->_r += PIPE_AUTO_DETECT_SIZE;
 #elif defined __GLIBC__
   fp->_IO_read_ptr = fp->_IO_read_base;
-#elif defined _MSC_VER || defined __MINGW_H || defined _ISO_STDIO_ISO_H
+#elif defined _MSC_VER || defined _WIN32 || defined _WIN64 || \
+      defined _ISO_STDIO_ISO_H || defined __sgi
   fp->_ptr = fp->_base;
 #else
   /* To fix this #error, either simply remove the #error line and live without
    * file-type detection with pipes, or add support for your compiler in the
-   * lines above.  Test with cat monkey.au | ./sox --info - */
+   * lines above.  Test with cat monkey.wav | ./sox --info - */
   #error FIX NEEDED HERE
   #define NO_REWIND_PIPE
   (void)fp;
@@ -481,7 +487,7 @@ static sox_format_t * open_read(
     }
 #ifndef NO_REWIND_PIPE
     else if (!(ft->handler.flags & SOX_FILE_NOSTDIO) &&
-        input_bufsiz >= AUTO_DETECT_SIZE) {
+        input_bufsiz >= PIPE_AUTO_DETECT_SIZE) {
       filetype = auto_detect_format(ft, lsx_find_file_extension(path));
       rewind_pipe(ft->fp);
       ft->tell_off = 0;
@@ -803,7 +809,7 @@ sox_format_handler_t const * sox_write_handler(
   else return NULL;
   if (!handler->startwrite && !handler->write) {
     if (filetype1)
-      lsx_fail("file type `%s' isn't writeable", filetype);
+      lsx_fail("file type `%s' isn't writable", filetype);
     return NULL;
   }
   if (filetype1)
