@@ -39,7 +39,7 @@ typedef struct {
   else { \
     SEP = (SEPARATORS)[strlen(SEPARATORS) - 1]; \
     n = sscanf(text, SCAN"%c", &VAR, &SEP); \
-    if (VAR < MIN || (n == 2 && !strchr(SEPARATORS, SEP))) \
+    if (n == 0 || VAR < MIN || (n == 2 && !strchr(SEPARATORS, SEP))) \
       return lsx_usage(effp); \
     text = end? end + 1 : text + strlen(text); \
   } \
@@ -121,7 +121,8 @@ static int create(sox_effect_t * effp, int argc, char * * argv)
     lsx_fail("must specify at least one output channel");
     return SOX_EOF;
   }
-  p->out_specs = lsx_calloc(p->num_out_channels = argc, sizeof(*p->out_specs));
+  p->num_out_channels = argc;
+  p->out_specs = lsx_calloc(p->num_out_channels, sizeof(*p->out_specs));
   return parse(effp, argv, 1); /* No channels yet; parse with dummy */
 }
 
@@ -151,6 +152,8 @@ static int start(sox_effect_t * effp)
     *effp->in_signal.mult /= max_sum;
   if (!non_integer)
     effp->out_signal.precision = effp->in_signal.precision;
+  else
+    effp->out_signal.precision = SOX_SAMPLE_PRECISION;
   show(p);
   return SOX_SUCCESS;
 }
@@ -189,7 +192,7 @@ sox_effect_handler_t const * lsx_remix_effect_fn(void)
 {
   static sox_effect_handler_t handler = {
     "remix", "[-m|-a] [-p] <0|in-chan[v|p|i volume]{,in-chan[v|p|i volume]}>",
-    SOX_EFF_MCHAN | SOX_EFF_CHAN | SOX_EFF_GAIN,
+    SOX_EFF_MCHAN | SOX_EFF_CHAN | SOX_EFF_GAIN | SOX_EFF_PREC,
     create, start, flow, NULL, NULL, closedown, sizeof(priv_t)
   };
   return &handler;
@@ -235,7 +238,6 @@ static int channels_start(sox_effect_t * effp)
         p->out_specs[j].in_specs[i].multiplier = 1. / in_per_out;
       }
     }
-    effp->out_signal.precision = SOX_SAMPLE_PRECISION;
   }
   else for (j = 0; j < num_out_channels; j++) {
     lsx_valloc(p->out_specs[j].in_specs, 1);
@@ -244,15 +246,39 @@ static int channels_start(sox_effect_t * effp)
     p->out_specs[j].in_specs[0].multiplier = 1;
   }
   effp->out_signal.channels = p->num_out_channels = num_out_channels;
+  effp->out_signal.precision = (effp->in_signal.channels > num_out_channels) ?
+    SOX_SAMPLE_PRECISION : effp->in_signal.precision;
   show(p);
   return SOX_SUCCESS;
 }
 
 sox_effect_handler_t const * lsx_channels_effect_fn(void)
 {
-  static sox_effect_handler_t handler = {
-    "channels", "number", SOX_EFF_MCHAN | SOX_EFF_CHAN,
-    channels_create, channels_start, flow, NULL, closedown, NULL, sizeof(priv_t)
-  };
+  static sox_effect_handler_t handler;
+  handler = *lsx_remix_effect_fn();
+  handler.name = "channels";
+  handler.usage = "number";
+  handler.flags &= ~SOX_EFF_GAIN;
+  handler.getopts = channels_create;
+  handler.start = channels_start;
+  return &handler;
+}
+
+/*------------------------- The `oops' effect alias --------------------------*/
+
+static int oops_getopts(sox_effect_t *effp, int argc, char **argv)
+{
+  char *args[] = {0, "1,2i", "1,2i"};
+  args[0] = argv[0];
+  return --argc? lsx_usage(effp) : create(effp, 3, args);
+}
+
+sox_effect_handler_t const * lsx_oops_effect_fn(void)
+{
+  static sox_effect_handler_t handler;
+  handler = *lsx_remix_effect_fn();
+  handler.name = "oops";
+  handler.usage = NULL;
+  handler.getopts = oops_getopts;
   return &handler;
 }
